@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 1999-2002, 2004-2011 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2002, 2004-2011, 2016, 2022 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
- * and/or modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either version 2
+ * and/or modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either version 2.1
  * of the License, or (at your option) any later version.
  *
  * The GNU LIBICONV Library is distributed in the hope that it will be
  * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with the GNU LIBICONV Library; see the file COPYING.LIB.
- * If not, see <http://www.gnu.org/licenses/>.
+ * If not, see <https://www.gnu.org/licenses/>.
  */
 
 /* This file defines all the converters. */
@@ -33,14 +33,16 @@ typedef struct conv_struct * conv_t;
  * Data type for conversion multibyte -> unicode
  */
 struct mbtowc_funcs {
-  int (*xxx_mbtowc) (conv_t conv, ucs4_t *pwc, unsigned char const *s, int n);
+  int (*xxx_mbtowc) (conv_t conv, ucs4_t *pwc, unsigned char const *s, size_t n);
   /*
-   * int xxx_mbtowc (conv_t conv, ucs4_t *pwc, unsigned char const *s, int n)
+   * int xxx_mbtowc (conv_t conv, ucs4_t *pwc, unsigned char const *s, size_t n)
    * converts the byte sequence starting at s to a wide character. Up to n bytes
    * are available at s. n is >= 1.
    * Result is number of bytes consumed (if a wide character was read),
-   * or -1 if invalid, or -2 if n too small, or -2-(number of bytes consumed)
-   * if only a shift sequence was read.
+   * or -1 if invalid, or -2 if n too small,
+   * or RET_SHIFT_ILSEQ(number of bytes consumed) if invalid input after a shift
+   * sequence was read,
+   * or RET_TOOFEW(number of bytes consumed) if only a shift sequence was read.
    */
   int (*xxx_flushwc) (conv_t conv, ucs4_t *pwc);
   /*
@@ -60,21 +62,23 @@ struct mbtowc_funcs {
 /* Retrieve the n from the encoded RET_... value. */
 #define DECODE_SHIFT_ILSEQ(r)  ((unsigned int)(RET_SHIFT_ILSEQ(0) - (r)) / 2)
 #define DECODE_TOOFEW(r)       ((unsigned int)(RET_TOOFEW(0) - (r)) / 2)
+/* Maximum value of n that may be used as argument to RET_SHIFT_ILSEQ or RET_TOOFEW. */
+#define RET_COUNT_MAX       ((INT_MAX / 2) - 1)
 
 /*
  * Data type for conversion unicode -> multibyte
  */
 struct wctomb_funcs {
-  int (*xxx_wctomb) (conv_t conv, unsigned char *r, ucs4_t wc, int n);
+  int (*xxx_wctomb) (conv_t conv, unsigned char *r, ucs4_t wc, size_t n);
   /*
-   * int xxx_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
+   * int xxx_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
    * converts the wide character wc to the character set xxx, and stores the
    * result beginning at r. Up to n bytes may be written at r. n is >= 1.
    * Result is number of bytes written, or -1 if invalid, or -2 if n too small.
    */
-  int (*xxx_reset) (conv_t conv, unsigned char *r, int n);
+  int (*xxx_reset) (conv_t conv, unsigned char *r, size_t n);
   /*
-   * int xxx_reset (conv_t conv, unsigned char *r, int n)
+   * int xxx_reset (conv_t conv, unsigned char *r, size_t n)
    * stores a shift sequences returning to the initial state beginning at r.
    * Up to n bytes may be written at r. n is >= 0.
    * Result is number of bytes written, or -2 if n too small.
@@ -286,6 +290,63 @@ typedef struct {
 #include "cp1125.h"
 #endif
 
+#ifdef USE_ZOS
+#define DEDUPLICATE_TABLES 1
+#include "ebcdic037.h"
+#include "ebcdic273.h"
+#include "ebcdic277.h"
+#include "ebcdic278.h"
+#include "ebcdic280.h"
+#include "ebcdic282.h"
+#include "ebcdic284.h"
+#include "ebcdic285.h"
+#include "ebcdic297.h"
+#include "ebcdic423.h"
+#include "ebcdic424.h"
+#include "ebcdic425.h"
+#include "ebcdic500.h"
+#include "ebcdic838.h"
+#include "ebcdic870.h"
+#include "ebcdic871.h"
+#include "ebcdic875.h"
+#include "ebcdic880.h"
+#include "ebcdic905.h"
+#include "ebcdic924.h"
+#include "ebcdic1025.h"
+#include "ebcdic1026.h"
+#include "ebcdic1047.h"
+#include "ebcdic1097.h"
+#include "ebcdic1112.h"
+#include "ebcdic1122.h"
+#include "ebcdic1123.h"
+#include "ebcdic1130.h"
+#include "ebcdic1132.h"
+#include "ebcdic1137.h"
+#include "ebcdic1140.h"
+#include "ebcdic1141.h"
+#include "ebcdic1142.h"
+#include "ebcdic1143.h"
+#include "ebcdic1144.h"
+#include "ebcdic1145.h"
+#include "ebcdic1146.h"
+#include "ebcdic1147.h"
+#include "ebcdic1148.h"
+#include "ebcdic1149.h"
+#include "ebcdic1153.h"
+#include "ebcdic1154.h"
+#include "ebcdic1155.h"
+#include "ebcdic1156.h"
+#include "ebcdic1157.h"
+#include "ebcdic1158.h"
+#include "ebcdic1160.h"
+#include "ebcdic1164.h"
+#include "ebcdic1165.h"
+#include "ebcdic1166.h"
+#include "ebcdic4971.h"
+#include "ebcdic12712.h"
+#include "ebcdic16804.h"
+#endif
+
 #ifdef USE_EXTRA
 #include "euc_jisx0213.h"
 #include "shift_jisx0213.h"
